\name{acRandomize}
\alias{acRandomize}
\alias{acRecruit}
\alias{trtSeqTab}
\alias{trtParTab}

\title{Simulate trial randomization}
\description{
Given a data.frame of patients, drug parameterization, and trial
characteristics, randomize the patients into the specified treatment arms
}
\usage{
acRandomize(patTab, trtSeqTab, trtParTab, randfunc = .randomize)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{patTab}{
    The patient demographic table, a data.frame containing simulated
    patients 
  }
  \item{trtSeqTab}{
    The treatment sequence table, a data.frame specifying the treatment sequence per arm
  }
  \item{trtParTab}{
    The treatment parameterization table, a data.frame parameterizing formulations
  }
  \item{randfunc}{
    Function determining randomization, \code{\link{blockrand}} is used
    by default.  
  }
}
\details{
  The patient demographic table (e.g., output from
  \code{\link{acRecruit}}) will be randomized to arms specified by
  the "treatment sequence table" (\code{trSeqTab}) according to the indicated
  randomization function (\code{\link{blockrand}} by default).  The
  treatment sequence table is comprised of drugs specified in \code{trtParTab}.

  Each object (row) of the treatment sequence table corresponds to a treatment sequence for an arm, taking the variables: \cr
\itemize{
  \item Arm       -- the arm (e.g., "A", "B", ...)
  \item DrugDose  -- an identifier (e.g., "Placebo" or "Test")
  \item DoseBegin -- start of dosing
  \item DoseEnd   -- end of dosing
}
  Each object (row) of the treatment parameterization table corresponds to a
  drug-dose combination with the following variables:
\itemize{
  \item DrugDose   -- an identifier (e.g., "Placebo" or "Test")
  \item emaxSx     -- longitudinal symptomatic Emax parameter \bold{specified
                on the logit scale}.  The function \code{\link{gLogitDelta}} 
	        will be useful for this transformation
  \item et50Sx     -- the \eqn{ET_{50}} for the symptomatic component of the
                drug effect
  \item et50SxWash -- the half-life for washout
  \item eDm        -- dose modifying effect, the proportional decrease in
  slope	
}

  Crossover designs can be coded by specifying the treatment period in
  the treatment sequence table.  Unspecified periods relative to the
  global time will assumed to be placebo dosed (but may alternatively be
  specified as natural progression) in \code{\link{acRun}} when
  simulating ADAS-cog values.  See below for examples.
  }
\value{
  The randomization table as a data.frame
}
\author{
  Dan Polhamus
}

\seealso{
  \code{\link{acRecruit}}
  \code{\link{acRun}}
  \code{\link{gLogitDelta}}
}
\examples{
## =============================================================================
## Parallel trial with a 2.5 point longitudinal improvement
## =============================================================================

data(posterior)

n.per.arm <- 100
n.enrolled <- n.per.arm * 2
treatments <-  c("Placebo", "Test") 

TrtSeqTable <- data.frame(Arm = LETTERS[1:2],
                          DrugDose = treatments, 
                          DoseBegin = c(0, 0), 
                          DoseEnd = c(78, 78)
                          )

lbMmse.use <- 14
ubMmse.use <- 26

## -----------------------------------------------------------------------------
## Drug parameters: 
##   * True effect at 24 weeks = 2.8
##   * W050 (half-life for washout) = 1 week (irrelevant, but need to specify a value)

TrtParTable <- data.frame(
                          DrugDose = treatments,
                          emaxSx = c(0, -2.5),
                          et50Sx = 1, 
                          et50SxWash = 1, 
                          eDm = c(0, 0.1)
                          )
p.use <- posterior[ sample(1:nrow(posterior), 1), ]
TrtParTable$emaxSx <- gLogitDelta(TrtParTable$emaxSx)$logitEmax
patientTable <- acRecruit(n.enrolled, p.use, lbMmse = lbMmse.use, ubMmse
             = ubMmse.use)
baseTable <- acRandomize(patientTable, TrtSeqTable, TrtParTable)


## =============================================================================
## Crossover design 
## =============================================================================                                    
data(posterior)

n.per.arm <- 30
n.enrolled <- n.per.arm * 2
treatments <-  c("Test") ## Both arms will receive test compound at some point. 

TrtSeqTable <- data.frame(Arm = LETTERS[1:2],
                          DrugDose = treatments, 
                          DoseBegin = c(0, 9), 
                          DoseEnd = c(6, 15)
                          )

lbMmse.use <- 14
ubMmse.use <- 26

## =============================================================================
## Drug parameters: 
##   * True effect at 24 weeks = 2.5
##   * W050 (half-life for washout) = 1 week

TrtParTable <- data.frame(
                          DrugDose = treatments,
                          emaxSx = -2.5,
                          et50Sx = 1,
                          et50SxWash = 1, 
                          eDm = 0 
                          )
p.use <- posterior[ sample(1:nrow(posterior), 1), ]
TrtParTable$emaxSx <- gLogitDelta(emaxSx)$logitEmax
                                    
patientTable <- acRecruit(n.enrolled, p.use, lbMmse = lbMmse.use, ubMmse = ubMmse.use)
baseTable <- acRandomize(patientTable, TrtSeqTable, TrtParTable)

## =============================================================================
## Delayed start
## =============================================================================

data(posterior)
n.per.arm <- 30
n.enrolled <- n.per.arm * 2
treatments <-  c("Test") 

t.global <- c(26 * (0:2), 26 * 2 + 13 + 26 * (0:1))

TrtSeqTable <- data.frame(Arm = LETTERS[1:2],
                          DrugDose = treatments, 
                          DoseBegin = c(0, 52), 
                          DoseEnd = max(t.global)
                          )

lbMmse.use <- 14
ubMmse.use <- 26

## =============================================================================
## Drug parameters: 

TrtParTable <- data.frame(
                          DrugDose = treatments,
                          emaxSx = 0,
                          et50Sx = 1, 
                          et50SxWash = 1, 
                          eDm = c(0.1) # proportional decrease (*not* proportion preserved)
                          )
  emaxSx <- TrtParTable$emaxSx
  p.use <- posterior[ sample(1:nrow(posterior), 1), ]

  TrtParTable$emaxSx <- gLogitDelta(emaxSx,
                                    xi = 1)$logitEmax
  
  patientTable <- acRecruit(n.enrolled, p.use, lbMmse = lbMmse.use, ubMmse = ubMmse.use)
  baseTable <- acRandomize(patientTable, TrtSeqTable, TrtParTable)

}
